@@ -7,8 +7,8 @@
 #ifndef NETWORKMANAGERQT_GRE_DEVICE_P_H
 #define NETWORKMANAGERQT_GRE_DEVICE_P_H
 
-#include "gredevice.h"
 #include "device_p.h"
+#include "gredevice.h"
 #include "manager.h"
 #include "manager_p.h"
 
@@ -16,13 +16,12 @@
 
 namespace NetworkManager
 {
-
 class GreDevicePrivate : public DevicePrivate
 {
     Q_OBJECT
 public:
     GreDevicePrivate(const QString &path, GreDevice *q);
-    virtual ~GreDevicePrivate();
+    ~GreDevicePrivate() override;
 
     OrgFreedesktopNetworkManagerDeviceGreInterface iface;
     ushort inputFlags;
